# DNAFMIndex

This project wraps **[TravisWheelerLab/AvxWindowFmIndex](https://github.com/TravisWheelerLab/AvxWindowFmIndex)**,
which is licensed under the BSD 3-Clause License.
Copyright (c) 2021, Tim Anderson.
